Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(632)

Unified Diff: runtime/vm/locations.h

Issue 19464002: Replaces Location::ToStackSlotAddress() with Location::ToStackSlotOffset() (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/locations.h
===================================================================
--- runtime/vm/locations.h (revision 25072)
+++ runtime/vm/locations.h (working copy)
@@ -281,8 +281,8 @@
return payload() - kStackIndexBias;
}
- // Return a memory operand for stack slot locations.
- Address ToStackSlotAddress() const;
+ // Returns the offset from the frame pointer for stack slot locations.
+ intptr_t ToStackSlotOffset() const;
regis 2013/07/17 16:35:19 You could add this new function, while leaving ToS
// Constants.
static Location RegisterOrConstant(Value* value);

Powered by Google App Engine
This is Rietveld 408576698